pub struct Session { /* private fields */ }
An active Neovim session.

Implementations

Connect to nvim instance via tcp

Connect to nvim instance via unix socket

Connect to a Neovim instance by spawning a new one.

Connect to a Neovim instance by spawning a new one

Connect to a Neovim instance by spawning a new one

stdin/stdout settings will be rewrited to Stdio::piped()

Connect to a Neovim instance that spawned this process over stdin/stdout.

Set call timeout

Start processing rpc response and notifications

Start processing rpc response and notifications

Start processing rpc response and notifications

Start processing rpc response and notifications

Sync call. Call can be made only after event loop begin processing

Create async call will be executed when only after call() function.

Wait dispatch thread to finish.

This can happens in case child process connection is lost for some reason.