pub struct Integer { /* private fields */ }
Represents a MessagePack integer, whether signed or unsigned.
A Value or ValueRef that contains integer can be constructed using From trait.
Returns true if the integer can be represented as i64.
Returns true if the integer can be represented as u64.
Returns the integer represented as i64 if possible, or else None.
Returns the integer represented as u64 if possible, or else None.
Returns the integer represented as f64 if possible, or else None.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
This method tests for
self and
other values to be equal, and is used
by
==.
Read more
This method tests for
!=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.