Struct neovim_lib::Utf8String
source · [−]pub struct Utf8String { /* private fields */ }Expand description
Represents an UTF-8 MessagePack string type.
According to the MessagePack spec, string objects may contain invalid byte sequence and the behavior of a deserializer depends on the actual implementation when it received invalid byte sequence. Deserializers should provide functionality to get the original byte array so that applications can decide how to handle the object.
Summarizing, it’s prohibited to instantiate a string type with invalid UTF-8 sequences, however
it is possible to obtain an underlying bytes that were attempted to convert to a String. This
may happen when trying to unpack strings that were decoded using older MessagePack spec with
raw types instead of string/binary.
Implementations
sourceimpl Utf8String
impl Utf8String
sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Returns the string reference if the string is valid UTF-8, or else None.
sourcepub fn as_err(&self) -> Option<&Utf8Error>
pub fn as_err(&self) -> Option<&Utf8Error>
Returns the underlying Utf8Error if the string contains invalud UTF-8 sequence, or
else None.
sourcepub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &mut [u8]impl Write for &mut [u8]impl Read for &[u8]
pub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &mut [u8]impl Write for &mut [u8]impl Read for &[u8]
Returns a byte slice of this Utf8String’s contents.
sourcepub fn into_str(self) -> Option<String>
pub fn into_str(self) -> Option<String>
Consumes this object, yielding the string if the string is valid UTF-8, or else None.
sourcepub fn into_bytes(self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn into_bytes(self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
Converts a Utf8String into a byte vector.
pub fn as_ref(&self) -> Utf8StringRef<'_>